@@ -15,7 +15,7 @@ from .status import LocationType, NormalStatus, UserContactType, WatchOnlineStat
 
 _LOGGER = logging.getLogger(__name__)
 
-_LIST_DICT: list[dict[str, Any]] = []
+LIST_DICT: list[dict[str, any]] = []
 
 
 class PyXploraApi(PyXplora):
@@ -53,8 +53,8 @@ class PyXploraApi(PyXplora):
                         # Try to login
                         try:
                             self._issueToken = await self._gqlHandler.login_a()
-                        except LoginError as err:
-                            self.error_message = err.message
+                        except LoginError as error:
+                            self.error_message = error.message
                         except Exception:
                             if retryCounter == self.maxRetries + 2:
                                 self.error_message = ErrorMSG.SERVER_ERR
@@ -79,9 +79,9 @@ class PyXploraApi(PyXplora):
             if token:
                 if token.get("user", {}):
                     if not self._childPhoneNumber:
-                        self.watchs = token.get("user", {}).get("children", _LIST_DICT)
+                        self.watchs = token.get("user", {}).get("children", LIST_DICT)
                     else:
-                        for watch in token.get("user", {}).get("children", _LIST_DICT):
+                        for watch in token.get("user", {}).get("children", LIST_DICT):
                             if watch["ward"]["phoneNumber"] in self._childPhoneNumber:
                                 self.watchs.append(watch)
                     self.user = token.get("user", {})
@@ -144,11 +144,11 @@ class PyXploraApi(PyXplora):
                 if not _contacts:
                     dataOk.append({})
                     return contacts
-                _contacts_contacts = _contacts.get("contacts", _LIST_DICT)
+                _contacts_contacts = _contacts.get("contacts", LIST_DICT)
                 if not _contacts_contacts:
                     dataOk.append({})
                     return contacts
-                for contact in _contacts.get("contacts", _LIST_DICT):
+                for contact in _contacts.get("contacts", LIST_DICT):
                     try:
                         xcoin = contact["contactUser"]["xcoin"]
                         id = contact["contactUser"]["id"]
